summaryrefslogtreecommitdiffstats
path: root/nserver/src/protocol.c
diff options
context:
space:
mode:
Diffstat (limited to 'nserver/src/protocol.c')
-rw-r--r--nserver/src/protocol.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/nserver/src/protocol.c b/nserver/src/protocol.c
index 6043dcf..da4141a 100644
--- a/nserver/src/protocol.c
+++ b/nserver/src/protocol.c
@@ -124,17 +124,17 @@ double sssample(char *key, double s)
double ssmean(char *key)
{
- check(hash != NULL, "hash not initialized");
+ check(key != NULL || strlen(key) < 1, "key invalid");
+ check(tst != NULL, "tstree not initialized");
- // 1. create bstring from 'key'.
- bstring k = bfromcstr(key);
+ // 1. Try to get Record for key.
+ Record *rec = (Record *) TSTree_search(tst, key, strlen(key));
- // 2. try to get Stats for key.
- Stats *st = (Stats *) Hashmap_get(hash, k);
- check(st != NULL, "stats not found for key");
+ check(rec != NULL, "record not found");
+ check(rec->st != NULL, "record's st invalid");
- // 3. get mean.
- double m = Stats_mean(st);
+ // 2. Get mean.
+ double m = Stats_mean(rec->st);
return m;
error: